=pod

=encoding utf-8

=head1 PURPOSE

Non-Moo* class used by no_moose.t.

=head1 AUTHOR

Toby Inkster E<lt>tobyink@cpan.orgE<gt>.

=head1 COPYRIGHT AND LICENCE

This software is copyright (c) 2013 by Toby Inkster.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

package FooBarTestClassPlain;

sub new { bless {}, shift }

1;

